==> pymrt-0.0.2.9-py2.py3-none-any.whl: scripts_cli/ernst_calc.py <==
#!python
# -*- coding: utf-8 -*-
"""
Calculate the optimal signal conditions (e.g. Ernst angle) for FLASH sequences.
"""

# ======================================================================
# :: Future Imports
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals

# ======================================================================
# :: Python Standard Library Imports
# import os  # Miscellaneous operating system interfaces
# import math  # Mathematical Functions
# import collections  # Container datatypes
import argparse  # Argument Parsing

# :: External Imports
# import scipy as sp  # SciPy (signal and image processing library)
# import matplotlib as mpl  # Matplotlib (2D/3D plotting library)
# import sympy as sym  # SymPy (symbolic CAS library)
# import PIL  # Python Image Library (image manipulation toolkit)
# import SimpleITK as sitk  # Image ToolKit Wrapper
# import nibabel as nib  # NiBabel (NeuroImaging I/O Library)
# import nipy  # NiPy (NeuroImaging in Python)
# import nipype  # NiPype (NiPy Pipelines and Interfaces)

# :: Local Imports
import pymrt as mrt
# import pymrt.utils
import pymrt.sequences.flash
# import pymrt.input_output
# import raster_geometry  # Create/manipulate N-dim raster geometric shapes.
from pymrt import INFO
from pymrt import VERB_LVL, D_VERB_LVL
from pymrt import msg, dbg


# ======================================================================
def handle_arg():
    """
    Handle command-line application arguments.
    """
    # :: Create Argument Parser
    arg_parser = argparse.ArgumentParser(
        description=__doc__,
        epilog='v.{} - {}\n{}'.format(
            INFO['version'], INFO['author'], INFO['license']),
        formatter_class=argparse.RawDescriptionHelpFormatter)
    # :: Add POSIX standard arguments
    arg_parser.add_argument(
        '--ver', '--version',
        version='%(prog)s - ver. {}\n{}\n{} {}\n{}'.format(
            INFO['version'],
            next(line for line in __doc__.splitlines() if line),
            INFO['copyright'], INFO['author'], INFO['notice']),
        action='version')
    arg_parser.add_argument(
        '-v', '--verbose',
        action='count', default=D_VERB_LVL,
        help='increase the level of verbosity [%(default)s]')
    arg_parser.add_argument(
        '-q', '--quiet',
        action='store_true',
        help='override verbosity settings to suppress output [%(default)s]')
    # :: Add additional arguments
    arg_parser.add_argument(
        '--t1', metavar='X',
        type=float, default=1000,
        help='set the T1 value in ms [%(default)s]')
    arg_parser.add_argument(
        '--tr', metavar='X',
        type=float, default=100,
        help='set the TR value in ms [%(default)s]')
    arg_parser.add_argument(
        '--fa', metavar='X',
        type=float, default=None,
        help='set the FA value in deg [%(default)s]')
    return arg_parser


# ======================================================================
def main():
    # :: handle program parameters
    arg_parser = handle_arg()
    args = arg_parser.parse_args()
    # fix verbosity in case of 'quiet'
    if args.quiet:
        args.verbose = VERB_LVL['none']
    # :: print debug info
    if args.verbose >= VERB_LVL['debug']:
        arg_parser.print_help()
        msg('\nARGS: ' + str(vars(args)), args.verbose, VERB_LVL['debug'])
    msg(__doc__.strip())

    val, name, units = pymrt.sequences.flash.ernst_calc(
        args.t1, args.tr, args.fa)
    print('{}={} {}'.format(name, val, units))


# ======================================================================
if __name__ == '__main__':
    main()

==> pymrt-0.0.2.13-py2.py3-none-any.whl: scripts_cli/ernst_calc.py <==
#!python
# -*- coding: utf-8 -*-
"""
Calculate the optimal signal conditions (e.g. Ernst angle) for FLASH sequences.
"""

# ======================================================================
# :: Future Imports
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals

# ======================================================================
# :: Python Standard Library Imports
# import os  # Miscellaneous operating system interfaces
# import math  # Mathematical Functions
# import collections  # Container datatypes
import argparse  # Argument Parsing

# :: External Imports
# import scipy as sp  # SciPy (signal and image processing library)
# import matplotlib as mpl  # Matplotlib (2D/3D plotting library)
# import sympy as sym  # SymPy (symbolic CAS library)
# import PIL  # Python Image Library (image manipulation toolkit)
# import SimpleITK as sitk  # Image ToolKit Wrapper
# import nibabel as nib  # NiBabel (NeuroImaging I/O Library)
# import nipy  # NiPy (NeuroImaging in Python)
# import nipype  # NiPype (NiPy Pipelines and Interfaces)

# :: Local Imports
import pymrt as mrt
# import pymrt.utils
import pymrt.sequences.flash
# import pymrt.input_output
# import raster_geometry  # Create/manipulate N-dim raster geometric shapes.
from pymrt import INFO
from pymrt import VERB_LVL, D_VERB_LVL
from pymrt import msg, dbg, fmt, fmtm


# ======================================================================
def handle_arg():
    """
    Handle command-line application arguments.
    """
    # :: Create Argument Parser
    arg_parser = argparse.ArgumentParser(
        description=__doc__,
        epilog=fmtm('v.{version} - {author}\n{license}', INFO),
        formatter_class=argparse.RawDescriptionHelpFormatter)
    # :: Add POSIX standard arguments
    arg_parser.add_argument(
        '--ver', '--version',
        version=fmt(
            '%(prog)s - ver. {version}\n{}\n{copyright} {author}\n{notice}',
            next(line for line in __doc__.splitlines() if line), **INFO),
        action='version')
    arg_parser.add_argument(
        '-v', '--verbose',
        action='count', default=D_VERB_LVL,
        help='increase the level of verbosity [%(default)s]')
    arg_parser.add_argument(
        '-q', '--quiet',
        action='store_true',
        help='override verbosity settings to suppress output [%(default)s]')
    # :: Add additional arguments
    arg_parser.add_argument(
        '--t1', metavar='X',
        type=float, default=1000,
        help='set the T1 value in ms [%(default)s]')
    arg_parser.add_argument(
        '--tr', metavar='X',
        type=float, default=100,
        help='set the TR value in ms [%(default)s]')
    arg_parser.add_argument(
        '--fa', metavar='X',
        type=float, default=None,
        help='set the FA value in deg [%(default)s]')
    return arg_parser


# ======================================================================
def main():
    # :: handle program parameters
    arg_parser = handle_arg()
    args = arg_parser.parse_args()
    # fix verbosity in case of 'quiet'
    if args.quiet:
        args.verbose = VERB_LVL['none']
    # :: print debug info
    if args.verbose >= VERB_LVL['debug']:
        arg_parser.print_help()
        msg('\nARGS: ' + str(vars(args)), args.verbose, VERB_LVL['debug'])
    msg(__doc__.strip())

    val, name, units = pymrt.sequences.flash.ernst_calc(
        args.t1, args.tr, args.fa)
    print('{}={} {}'.format(name, val, units))


# ======================================================================
if __name__ == '__main__':
    main()
